RCacheMethodKey class

Constructors

RCacheMethodKey()

Properties

clear ↔ String
getter/setter pair
common ↔ String
getter/setter pair
credentials ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
read ↔ RCacheMethodKeyRead
getter/setter pair
remove ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
save ↔ RCacheMethodKeySave
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited