RCacheMethodKeyRead class

Constructors

RCacheMethodKeyRead()

Properties

array ↔ String
getter/setter pair
bool ↔ String
getter/setter pair
double ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integer ↔ String
getter/setter pair
map ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string ↔ String
getter/setter pair
uint8List ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited